@@ -17,11 +17,13 @@ DATA = [
 
     ## F-route
     '60.43.36.253',
-    '203.143.121.217',
 
     ## livedoor
     '203.104.254.0/24',
 
     ## goo
     '210.150.10.32/27',
+
+    ## baidu
+    '119.63.195.0/24',
 ]
